program PES_SO3

 ! Fortran 90 routine for calculating potential energy values for SO3 
 !
 ! Parameters:  
 ! 
 ! number of parameters and maximum number of ab initio points   
 !
 integer,parameter          ::  parmax=307,enermax =100000   
 !
 ! where the output goes to 
 ! 
 integer,parameter          :: f_inp=5, f_out=6
 !
 ! Universal constants 
 ! 
 double precision,parameter :: bohr = 0.52917715e+00,hartre=2.194746354d+05,pi=3.141592653589793
 !
 integer           :: i,npts,numpar,nrow ! just integers  
 ! 
 character(len=80) :: title(4),longlabel ! input title of the job from the first four input lines 
 character(len=1)  :: mark           ! used at the parameters output to mark the dependent or independent ones 
 character(len=10) :: label          ! Temporary label 
 double precision  :: wtsum,ssq,rms  ! 
 character(len=10) :: parnam(parmax) ! Names of the parameters, as they appear in the input file   !
 ! some variables 
 !
 double precision  :: v,potential
 double precision  :: r14,r24,r34,alpha1,alpha2,alpha3
 double precision  :: ve
 integer           :: i1,i2
 integer           :: ivar(parmax)
  double precision :: local(6)
 integer           :: alloc,ivartmp,nused
 integer           :: max_pnts,ipar
 logical           :: yes,ifopen
 double precision  :: conv_lenght,conv_energy,paramtmp
 
 !
 ! some matrices, to be allocated  
 !
 double precision, allocatable :: param(:)
 double precision, allocatable :: blen1(:),blen2(:),blen3(:)
 double precision, allocatable :: bang1(:),bang2(:),bang3(:),energy(:)
 double precision, allocatable :: eps(:),wt(:)
 
 !
 ! Array's allocation:
 !

 allocate (param(parmax),blen1(enermax),blen2(enermax),blen3(enermax),&
           bang1(enermax),bang2(enermax),bang3(enermax),energy(enermax),eps(enermax),wt(enermax),stat=alloc)
 if (alloc/=0) then 
  write(6,"('arrays - out of memory')")  
  stop
 endif
 
 !
 ! Input data from file: 
 !
 call skiplines(f_inp,1)
 !
 !  input the job title 
 !
 do i=1,4
   read  (f_inp,"(a80)") title(i)
 enddo
 !
 !  output the job title 
 !
 write (f_out,"(3(132('*')/),16('*'),100x,16('*'))")
 do i =1,4 
   write (f_out,"((16('*'),10x,a80,10x,16('*')))") title(i)
 enddo 
 write (f_out,"(3(132('*')/))") 
 !write (f_out,"(' ',16('*'),100x,16('*')/' ',3(132('*')/' '))") 
 !
 call skiplines(f_inp,4)
 !
 !
 ! Converiosn factors:
 ! bond length 
 read (f_inp,*) conv_lenght
 ! energies 
 read (f_inp,*) conv_energy
 !
 ! input potential parameters 
 !
 call skiplines(f_inp,3)
 do i = 1,parmax
   read (f_inp,"(a80)") longlabel
   read (longlabel,"(a10)") label
   read (longlabel(11:80),*) ivartmp,paramtmp
   if (ivartmp/=-1) then 
     parnam(i) = label 
     ivar(i)   = ivartmp
     param(i)  = paramtmp
   else 
     write(f_out,"('Wrong number of parameters (',I6,'), has to be (',I6,')')") i,parmax
     stop 'Too few parameters'
   endif 
 enddo 

 read (f_inp,"(a80)") longlabel
 write(6,"(a80)") longlabel
 read (longlabel,"(a10,i4,d18.8)") label,ivartmp,paramtmp
 if (ivartmp/=-1) then 
   write(f_out,"('Wrong number of parameters (',I6,'), has to be (',I6,')')") i,parmax
   stop 'Too many parameters'
 endif 
 !
 ! Output of the potential parameters 
 ! 
 write (f_out,"('0',5x,12('*'),' potential energy expansion coefficients (cm-1) ',12('*')//)")
 do i = 1,int(parmax/3)*3,3 
 write (f_out,"(3('  ',a9,'=',f16.3))") parnam(i),param(i),     &
                                        parnam(i+1),param(i+1), &
                                        parnam(i+2),param(i+2)
 enddo 
 write (f_out,"(3('  ',a9,'=',f16.3))") (parnam(int(parmax/3)*3+i), &
                                         param(int(parmax/3)*3+i),i=1,mod(parmax,3))


!---input energy values------!
 npts = 0
 yes = .true. 
 do while( yes )
    npts=npts+1
    if (npts>enermax) then
      write(f_out,"('Too many ab initio points, increase enermax:',I6,' vs ',I6)") npts,enermax
      endif
    read (f_inp,*) blen1(npts),blen2(npts),blen3(npts) &
                 , bang1(npts),bang2(npts),bang3(npts) &
                 , energy(npts),wt(npts)
    if ( blen1(npts).lt.0.0 ) yes = .false.
 enddo 
 !
 ! Number of ab initio points  
 npts=npts-1
 ! 
 ! "normalising" the weight factors
 nused=0
 wtsum=0.0d0
 do i=1,npts
   if (wt(i) > 0.0) nused=nused+1
   wtsum=wtsum+wt(i)
 enddo 
 wtsum=wtsum/nused
 wt(:)=wt(:)/wtsum
 !
 ! Convert the energies to the internal dimension, e.g. 1/cm 
 energy(:) = energy(:)*conv_energy
 !
 write (f_out,"(/'0',5x,12('*'),' Calculated energies  ',12('*')//)")
 !
     ssq=0.0d+00
     rms=0.0d+00
     do nrow=1,npts
       !
       ! Running bond lenght 
       !
       local(1)=blen1(nrow)*conv_lenght
       local(2)=blen2(nrow)*conv_lenght
       local(3)=blen3(nrow)*conv_lenght
       !
       ! Running interbond angles
       !
       local(4)=bang1(nrow)*pi/1.8d+02
       local(5)=bang2(nrow)*pi/1.8d+02
       local(6)=bang3(nrow)*pi/1.8d+02
       ! 
       ! Value of the potential energy fucntion at the current geometry 
       !
       v = potential(parmax,param,local)
       !
       eps(nrow) = energy(nrow)-v
       !
       ! Weighted st. square deviation 
       !
       ssq=ssq+eps(nrow)*eps(nrow)*wt(nrow)
       !
       ! mean square 
       !
       rms=rms+eps(nrow)*eps(nrow)

     enddo  ! ---  nrow

     ssq=dsqrt(ssq/float(npts))
     rms = dsqrt(rms/npts)
     ve = param(4)
 
     do nrow=1,npts
       !
       r14=blen1(nrow)*conv_lenght
       r24=blen2(nrow)*conv_lenght
       r34=blen3(nrow)*conv_lenght
       !
       alpha1=bang1(nrow)
       alpha2=bang2(nrow)
       alpha3=bang3(nrow)

       v = energy(nrow)-eps(nrow)
        write (f_out,"(3f8.3,3f8.1,3f12.2,2x,d8.2)")        & 
          r14,r24,r34,                                      &
          alpha1,alpha2,alpha3,                             &
          energy(nrow)-ve,v-ve,eps(nrow),                   &
          wt(nrow)

      enddo



 end


 recursive double precision function potential(parmax,param,local)

 integer,intent(in)          :: parmax
 double precision,intent(in) ::  param(parmax)
 double precision,intent(in) ::  local(6)
 integer                     :: order=6
 double precision            ::  ZPE=0
 double precision         ::  y1,y2,y3,y4,y5
 double precision         ::  s4a,s4b,alpha,rho,coro,s3a,s3b,s3aa2,s3ba2
 double precision         ::  s3aa13,s3ba13,s3aa3,s3ba3,s3aa113,s3ba113,s3aa133,s3ba133

 double precision         ::  v,v0,rhoe,pi,v1,v2,v3,v4,v5,v6

 double precision         ::  sinrho,r14,r24,r34,alpha1,alpha2,alpha3

                        
  double precision &
      fea    ,fea1  ,                                    &
      fea11  ,fea12  ,fea14  ,fea44  ,                     &
      fea111 ,fea112 ,fea114 ,fea123 ,                     &
      fea124 ,fea144 ,fea155 ,fea455 ,                     &
      fea1111,fea1112,fea1114,fea1122,                     &
      fea1123,fea1124,fea1125,fea1144,                     &
      fea1155,fea1244,fea1255,fea1444,                     &
      fea1455,fea4444
      double precision ::   &
      fea44444 ,fea33455 ,fea33445 ,fea33345 ,fea33344 ,&
      fea33334 ,fea33333 ,fea25555 ,fea24455 ,fea24445 ,fea23333 ,&
      fea13455 ,fea13445 ,fea13345 ,fea12355 ,fea11334 ,fea11333 ,&
      fea11255 ,fea11245 ,fea11234 ,fea11233 ,fea11135 ,fea11134 ,&
      fea11123 ,fea555555,fea444444,fea335555,fea334455,fea334445,&
      fea333555,fea333333,fea244555,fea244455,fea233445,fea233444,&
      fea233345,fea233344,fea233335,fea223355,fea222335,fea222334,&
      fea222333,fea222255,fea222245,fea222233,fea222224,fea145555,&
      fea134444,fea133444,fea133345,fea133334,fea133333,fea124555,&
      fea124455,fea123455,fea123345,fea113555,fea113345,fea112355,&
      fea112335,fea112233,fea111444,fea111234,fea111233,fea111123

  double precision v56,s1,s2,s3,s4,s5,s6
  
  double precision :: &      
      Rhoedg,re14,aa1,ve  ,  &
      f1a,f2a,f3a,f4a,f5a,f6a,f7a,f8a, &
      f1a1,f2a1,f3a1,f4a1,f5a1,f6a1,  &
      f0a11,f1a11,f2a11,f3a11,f4a11, &
      f0a12,f1a12,f2a12,f3a12,f4a12, &
      f0a14,f1a14,f2a14,f3a14,f4a14, &
      f0a44,f1a44,f2a44,f3a44,f4a44, &
      f0a111,f1a111,f2a111,f3a111  , &
      f0a112,f1a112,f2a112,f3a112  , &
      f0a114,f1a114,f2a114,f3a114  , &
      f0a123,f1a123,f2a123,f3a123  , &
      f0a124,f1a124,f2a124,f3a124  , &
      f0a144,f1a144,f2a144,f3a144  , &
      f0a155,f1a155,f2a155,f3a155  , &
      f0a455,f1a455,f2a455,f3a455  , &
      f0a1111,f1a1111,f2a1111      , &
      f0a1112,f1a1112,f2a1112      , &
      f0a1114,f1a1114,f2a1114      , &
      f0a1122,f1a1122,f2a1122      , &
      f0a1123,f1a1123,f2a1123      , &
      f0a1124,f1a1124,f2a1124      , &
      f0a1125,f1a1125,f2a1125      , &
      f0a1144,f1a1144,f2a1144      , &
      f0a1155,f1a1155,f2a1155      , &
      f0a1244,f1a1244,f2a1244      , &
      f0a1255,f1a1255,f2a1255      , &
      f0a1444,f1a1444,f2a1444      , &
      f0a1455,f1a1455,f2a1455      , &
      f0a4444,f1a4444,f2a4444      , &
      f0a44444 ,f1a44444 ,           &
      f2a44444 ,f0a33455 ,f1a33455 ,f2a33455 ,f0a33445 ,f1a33445 ,&
      f2a33445 ,f0a33345 ,f1a33345 ,f2a33345 ,f0a33344 ,f1a33344 ,&
      f2a33344 ,f0a33334 ,f1a33334 ,f2a33334 ,f0a33333 ,f1a33333 ,&
      f2a33333 ,f0a25555 ,f1a25555 ,f2a25555 ,f0a24455 ,f1a24455 ,&
      f2a24455 ,f0a24445 ,f1a24445 ,f2a24445 ,f0a23333 ,f1a23333 ,&
      f2a23333 ,f0a13455 ,f1a13455 ,f2a13455 ,f0a13445 ,f1a13445 ,&
      f2a13445 ,f0a13345 ,f1a13345 ,f2a13345 ,f0a12355 ,f1a12355 ,&
      f2a12355 ,f0a11334 ,f1a11334 ,f2a11334 ,f0a11333 ,f1a11333 ,&
      f2a11333 ,f0a11255 ,f1a11255 ,f2a11255 ,f0a11245 ,f1a11245 ,&
      f2a11245 ,f0a11234 ,f1a11234 ,f2a11234 ,f0a11233 ,f1a11233 ,&
      f2a11233 ,f0a11135 ,f1a11135 ,f2a11135 ,f0a11134 ,f1a11134 ,&
      f2a11134 ,f0a11123 ,f1a11123 ,f2a11123 ,f0a555555,f1a555555,&
      f2a555555,f0a444444,f1a444444,f2a444444,f0a335555,f1a335555,&
      f2a335555,f0a334455,f1a334455,f2a334455,f0a334445,f1a334445,&
      f2a334445,f0a333555,f1a333555,f2a333555,f0a333333,f1a333333,&
      f2a333333,f0a244555,f1a244555,f2a244555,f0a244455,f1a244455,&
      f2a244455,f0a233445,f1a233445,f2a233445,f0a233444,f1a233444,&
      f2a233444,f0a233345,f1a233345,f2a233345,f0a233344,f1a233344,&
      f2a233344,f0a233335,f1a233335,f2a233335,f0a223355,f1a223355,&
      f2a223355,f0a222335,f1a222335,f2a222335,f0a222334,f1a222334,&
      f2a222334,f0a222333,f1a222333,f2a222333,f0a222255,f1a222255,&
      f2a222255,f0a222245,f1a222245,f2a222245,f0a222233,f1a222233,&
      f2a222233,f0a222224,f1a222224,f2a222224,f0a145555,f1a145555,&
      f2a145555,f0a134444,f1a134444,f2a134444,f0a133444,f1a133444,&
      f2a133444,f0a133345,f1a133345,f2a133345,f0a133334,f1a133334,&
      f2a133334,f0a133333,f1a133333,f2a133333,f0a124555,f1a124555,&
      f2a124555,f0a124455,f1a124455,f2a124455,f0a123455,f1a123455,&
      f2a123455,f0a123345,f1a123345,f2a123345,f0a113555,f1a113555,&
      f2a113555,f0a113345,f1a113345,f2a113345,f0a112355,f1a112355,&
      f2a112355,f0a112335,f1a112335,f2a112335,f0a112233,f1a112233,&
      f2a112233,f0a111444,f1a111444,f2a111444,f0a111234,f1a111234,&
      f2a111234,f0a111233,f1a111233,f2a111233,f0a111123,f1a111123,&
      f2a111123




  !-------------------------------

   rhoedg     = param(  1)
   pi=3.141592653589793
   rhoe=pi*rhoedg/1.8d+02
   re14       = param(  2)
   aa1        = param(  3)
   ve         = param(  4)
   f1a        = param(  5)
   f2a        = param(  6)
   f3a        = param(  7)
   f4a        = param(  8)
   f5a        = param(  9)
   f6a        = param( 10)
   f7a        = param( 11)
   f8a        = param( 12)
   f1a1       = param( 13)
   f2a1       = param( 14)
   f3a1       = param( 15)
   f4a1       = param( 16)
   f5a1       = param( 17)
   f6a1       = param( 18)
   f0a11      = param( 19)
   f1a11      = param( 20)
   f2a11      = param( 21)
   f3a11      = param( 22)
   f4a11      = param( 23)
   f0a12      = param( 24)
   f1a12      = param( 25)
   f2a12      = param( 26)
   f3a12      = param( 27)
   f4a12      = param( 28)
   f0a14      = param( 29)
   f1a14      = param( 30)
   f2a14      = param( 31)
   f3a14      = param( 32)
   f4a14      = param( 33)
   f0a44      = param( 34)
   f1a44      = param( 35)
   f2a44      = param( 36)
   f3a44      = param( 37)
   f4a44      = param( 38)
   f0a111     = param( 39)
   f1a111     = param( 40)
   f2a111     = param( 41)
   f3a111     = param( 42)
   f0a112     = param( 43)
   f1a112     = param( 44)
   f2a112     = param( 45)
   f3a112     = param( 46)
   f0a114     = param( 47)
   f1a114     = param( 48)
   f2a114     = param( 49)
   f3a114     = param( 50)
   f0a123     = param( 51)
   f1a123     = param( 52)
   f2a123     = param( 53)
   f3a123     = param( 54)
   f0a124     = param( 55)
   f1a124     = param( 56)
   f2a124     = param( 57)
   f3a124     = param( 58)
   f0a144     = param( 59)
   f1a144     = param( 60)
   f2a144     = param( 61)
   f3a144     = param( 62)
   f0a155     = param( 63)
   f1a155     = param( 64)
   f2a155     = param( 65)
   f3a155     = param( 66)
   f0a455     = param( 67)
   f1a455     = param( 68)
   f2a455     = param( 69)
   f3a455     = param( 70)
   f0a1111    = param( 71)
   f1a1111    = param( 72)
   f2a1111    = param( 73)
   f0a1112    = param( 74)
   f1a1112    = param( 75)
   f2a1112    = param( 76)
   f0a1114    = param( 77)
   f1a1114    = param( 78)
   f2a1114    = param( 79)
   f0a1122    = param( 80)
   f1a1122    = param( 81)
   f2a1122    = param( 82)
   f0a1123    = param( 83)
   f1a1123    = param( 84)
   f2a1123    = param( 85)
   f0a1124    = param( 86)
   f1a1124    = param( 87)
   f2a1124    = param( 88)
   f0a1125    = param( 89)
   f1a1125    = param( 90)
   f2a1125    = param( 91)
   f0a1144    = param( 92)
   f1a1144    = param( 93)
   f2a1144    = param( 94)
   f0a1155    = param( 95)
   f1a1155    = param( 96)
   f2a1155    = param( 97)
   f0a1244    = param( 98)
   f1a1244    = param( 99)
   f2a1244    = param(100)
   f0a1255    = param(101)
   f1a1255    = param(102)
   f2a1255    = param(103)
   f0a1444    = param(104)
   f1a1444    = param(105)
   f2a1444    = param(106)
   f0a1455    = param(107)
   f1a1455    = param(108)
   f2a1455    = param(109)
   f0a4444    = param(110)
   f1a4444    = param(111)
   f2a4444    = param(112)
   f0a44444   = param(113)
   f1a44444   = param(114)
   f2a44444   = param(115)
   f0a33455   = param(116)
   f1a33455   = param(117)
   f2a33455   = param(118)
   f0a33445   = param(119)
   f1a33445   = param(120)
   f2a33445   = param(121)
   f0a33345   = param(122)
   f1a33345   = param(123)
   f2a33345   = param(124)
   f0a33344   = param(125)
   f1a33344   = param(126)
   f2a33344   = param(127)
   f0a33334   = param(128)
   f1a33334   = param(129)
   f2a33334   = param(130)
   f0a33333   = param(131)
   f1a33333   = param(132)
   f2a33333   = param(133)
   f0a25555   = param(134)
   f1a25555   = param(135)
   f2a25555   = param(136)
   f0a24455   = param(137)
   f1a24455   = param(138)
   f2a24455   = param(139)
   f0a24445   = param(140)
   f1a24445   = param(141)
   f2a24445   = param(142)
   f0a23333   = param(143)
   f1a23333   = param(144)
   f2a23333   = param(145)
   f0a13455   = param(146)
   f1a13455   = param(147)
   f2a13455   = param(148)
   f0a13445   = param(149)
   f1a13445   = param(150)
   f2a13445   = param(151)
   f0a13345   = param(152)
   f1a13345   = param(153)
   f2a13345   = param(154)
   f0a12355   = param(155)
   f1a12355   = param(156)
   f2a12355   = param(157)
   f0a11334   = param(158)
   f1a11334   = param(159)
   f2a11334   = param(160)
   f0a11333   = param(161)
   f1a11333   = param(162)
   f2a11333   = param(163)
   f0a11255   = param(164)
   f1a11255   = param(165)
   f2a11255   = param(166)
   f0a11245   = param(167)
   f1a11245   = param(168)
   f2a11245   = param(169)
   f0a11234   = param(170)
   f1a11234   = param(171)
   f2a11234   = param(172)
   f0a11233   = param(173)
   f1a11233   = param(174)
   f2a11233   = param(175)
   f0a11135   = param(176)
   f1a11135   = param(177)
   f2a11135   = param(178)
   f0a11134   = param(179)
   f1a11134   = param(180)
   f2a11134   = param(181)
   f0a11123   = param(182)
   f1a11123   = param(183)
   f2a11123   = param(184)
   f0a555555  = param(185)
   f1a555555  = param(186)
   f2a555555  = param(187)
   f0a444444  = param(188)
   f1a444444  = param(189)
   f2a444444  = param(190)
   f0a335555  = param(191)
   f1a335555  = param(192)
   f2a335555  = param(193)
   f0a334455  = param(194)
   f1a334455  = param(195)
   f2a334455  = param(196)
   f0a334445  = param(197)
   f1a334445  = param(198)
   f2a334445  = param(199)
   f0a333555  = param(200)
   f1a333555  = param(201)
   f2a333555  = param(202)
   f0a333333  = param(203)
   f1a333333  = param(204)
   f2a333333  = param(205)
   f0a244555  = param(206)
   f1a244555  = param(207)
   f2a244555  = param(208)
   f0a244455  = param(209)
   f1a244455  = param(210)
   f2a244455  = param(211)
   f0a233445  = param(212)
   f1a233445  = param(213)
   f2a233445  = param(214)
   f0a233444  = param(215)
   f1a233444  = param(216)
   f2a233444  = param(217)
   f0a233345  = param(218)
   f1a233345  = param(219)
   f2a233345  = param(220)
   f0a233344  = param(221)
   f1a233344  = param(222)
   f2a233344  = param(223)
   f0a233335  = param(224)
   f1a233335  = param(225)
   f2a233335  = param(226)
   f0a223355  = param(227)
   f1a223355  = param(228)
   f2a223355  = param(229)
   f0a222335  = param(230)
   f1a222335  = param(231)
   f2a222335  = param(232)
   f0a222334  = param(233)
   f1a222334  = param(234)
   f2a222334  = param(235)
   f0a222333  = param(236)
   f1a222333  = param(237)
   f2a222333  = param(238)
   f0a222255  = param(239)
   f1a222255  = param(240)
   f2a222255  = param(241)
   f0a222245  = param(242)
   f1a222245  = param(243)
   f2a222245  = param(244)
   f0a222233  = param(245)
   f1a222233  = param(246)
   f2a222233  = param(247)
   f0a222224  = param(248)
   f1a222224  = param(249)
   f2a222224  = param(250)
   f0a145555  = param(251)
   f1a145555  = param(252)
   f2a145555  = param(253)
   f0a134444  = param(254)
   f1a134444  = param(255)
   f2a134444  = param(256)
   f0a133444  = param(257)
   f1a133444  = param(258)
   f2a133444  = param(259)
   f0a133345  = param(260)
   f1a133345  = param(261)
   f2a133345  = param(262)
   f0a133334  = param(263)
   f1a133334  = param(264)
   f2a133334  = param(265)
   f0a133333  = param(266)
   f1a133333  = param(267)
   f2a133333  = param(268)
   f0a124555  = param(269)
   f1a124555  = param(270)
   f2a124555  = param(271)
   f0a124455  = param(272)
   f1a124455  = param(273)
   f2a124455  = param(274)
   f0a123455  = param(275)
   f1a123455  = param(276)
   f2a123455  = param(277)
   f0a123345  = param(278)
   f1a123345  = param(279)
   f2a123345  = param(280)
   f0a113555  = param(281)
   f1a113555  = param(282)
   f2a113555  = param(283)
   f0a113345  = param(284)
   f1a113345  = param(285)
   f2a113345  = param(286)
   f0a112355  = param(287)
   f1a112355  = param(288)
   f2a112355  = param(289)
   f0a112335  = param(290)
   f1a112335  = param(291)
   f2a112335  = param(292)
   f0a112233  = param(293)
   f1a112233  = param(294)
   f2a112233  = param(295)
   f0a111444  = param(296)
   f1a111444  = param(297)
   f2a111444  = param(298)
   f0a111234  = param(299)
   f1a111234  = param(300)
   f2a111234  = param(301)
   f0a111233  = param(302)
   f1a111233  = param(303)
   f2a111233  = param(304)
   f0a111123  = param(305)
   f1a111123  = param(306)
   f2a111123  = param(307)


   r14    = local(1) ;  r24    = local(2) ;  r34    = local(3)
   alpha1 = local(4) ;  alpha2 = local(5) ;  alpha3 = local(6)

   y1=1.0d+00-exp(-aa1*(r14-re14))
   y2=1.0d+00-exp(-aa1*(r24-re14))
   y3=1.0d+00-exp(-aa1*(r34-re14))

   y4=(2.d0*alpha1-alpha2-alpha3)/sqrt(6.d0)
   y5=(alpha2-alpha3)/sqrt(2.d0)

   alpha=(alpha1+alpha2+alpha3)/3.d0
   !rho=pi-dasin(2.d0*sin(alpha*0.5d0)/dsqrt(3.d0))

   if ( 2.d0*sin(alpha*0.5d0)/dsqrt(3.d0).ge.1.0d0 ) then 
     rho = 0.5d0*pi   
     sinrho=1.d0 
   else 
     rho=pi-dasin(2.d0*sin(alpha*0.5d0)/dsqrt(3.d0))
!    sinrho = sin(rho)
     sinrho = 2.d0*sin(alpha*0.5d0)/dsqrt(3.d0)
   endif 

   coro=(sin(rhoe)-sinrho)


   ! potential energy function values

   v0=ve-ZPE+f1a*coro+f2a*coro**2+f3a*coro**3+f4a*coro**4+f5a*coro**5 &
        +f6a*coro**6+f7a*coro**7+f8a*coro**8

  ! coro=rho-rhoe


  fea1= f1a1*coro+f2a1*coro**2+f3a1*coro**3+f4a1*coro**4+f5a1*coro**5+f6a1*coro**6

  fea11=   f0a11+f1a11*coro+f2a11*coro**2+f3a11*coro**3+f4a11*coro**4
  fea12=   f0a12+f1a12*coro+f2a12*coro**2+f3a12*coro**3+f4a12*coro**4
  fea14=   f0a14+f1a14*coro+f2a14*coro**2+f3a14*coro**3+f4a14*coro**4
  fea44=   f0a44+f1a44*coro+f2a44*coro**2+f3a44*coro**3+f4a44*coro**4
 
  fea111= f0a111+f1a111*coro+f2a111*coro**2+f3a111*coro**3
  fea112= f0a112+f1a112*coro+f2a112*coro**2+f3a112*coro**3
  fea114= f0a114+f1a114*coro+f2a114*coro**2+f3a114*coro**3
  fea123= f0a123+f1a123*coro+f2a123*coro**2+f3a123*coro**3
  fea124= f0a124+f1a124*coro+f2a124*coro**2+f3a124*coro**3
  fea144= f0a144+f1a144*coro+f2a144*coro**2+f3a144*coro**3
  fea155= f0a155+f1a155*coro+f2a155*coro**2+f3a155*coro**3
  fea455= f0a455+f1a455*coro+f2a455*coro**2+f3a455*coro**3

  fea1111= f0a1111+f1a1111*coro+f2a1111*coro**2
  fea1112= f0a1112+f1a1112*coro+f2a1112*coro**2
  fea1114= f0a1114+f1a1114*coro+f2a1114*coro**2
  fea1122= f0a1122+f1a1122*coro+f2a1122*coro**2
  fea1123= f0a1123+f1a1123*coro+f2a1123*coro**2
  fea1124= f0a1124+f1a1124*coro+f2a1124*coro**2
  fea1125= f0a1125+f1a1125*coro+f2a1125*coro**2
  fea1144= f0a1144+f1a1144*coro+f2a1144*coro**2
  fea1155= f0a1155+f1a1155*coro+f2a1155*coro**2
  fea1244= f0a1244+f1a1244*coro+f2a1244*coro**2
  fea1255= f0a1255+f1a1255*coro+f2a1255*coro**2
  fea1444= f0a1444+f1a1444*coro+f2a1444*coro**2
  fea1455= f0a1455+f1a1455*coro+f2a1455*coro**2
  fea4444= f0a4444+f1a4444*coro+f2a4444*coro**2

  fea44444 = f0a44444  + f1a44444 *coro+ f2a44444 *coro**2
  fea33455 = f0a33455  + f1a33455 *coro+ f2a33455 *coro**2
  fea33445 = f0a33445  + f1a33445 *coro+ f2a33445 *coro**2
  fea33345 = f0a33345  + f1a33345 *coro+ f2a33345 *coro**2
  fea33344 = f0a33344  + f1a33344 *coro+ f2a33344 *coro**2
  fea33334 = f0a33334  + f1a33334 *coro+ f2a33334 *coro**2
  fea33333 = f0a33333  + f1a33333 *coro+ f2a33333 *coro**2
  fea25555 = f0a25555  + f1a25555 *coro+ f2a25555 *coro**2
  fea24455 = f0a24455  + f1a24455 *coro+ f2a24455 *coro**2
  fea24445 = f0a24445  + f1a24445 *coro+ f2a24445 *coro**2
  fea23333 = f0a23333  + f1a23333 *coro+ f2a23333 *coro**2
  fea13455 = f0a13455  + f1a13455 *coro+ f2a13455 *coro**2
  fea13445 = f0a13445  + f1a13445 *coro+ f2a13445 *coro**2
  fea13345 = f0a13345  + f1a13345 *coro+ f2a13345 *coro**2
  fea12355 = f0a12355  + f1a12355 *coro+ f2a12355 *coro**2
  fea11334 = f0a11334  + f1a11334 *coro+ f2a11334 *coro**2
  fea11333 = f0a11333  + f1a11333 *coro+ f2a11333 *coro**2
  fea11255 = f0a11255  + f1a11255 *coro+ f2a11255 *coro**2
  fea11245 = f0a11245  + f1a11245 *coro+ f2a11245 *coro**2
  fea11234 = f0a11234  + f1a11234 *coro+ f2a11234 *coro**2
  fea11233 = f0a11233  + f1a11233 *coro+ f2a11233 *coro**2
  fea11135 = f0a11135  + f1a11135 *coro+ f2a11135 *coro**2
  fea11134 = f0a11134  + f1a11134 *coro+ f2a11134 *coro**2
  fea11123 = f0a11123  + f1a11123 *coro+ f2a11123 *coro**2
  fea555555= f0a555555 + f1a555555*coro+ f2a555555*coro**2
  fea444444= f0a444444 + f1a444444*coro+ f2a444444*coro**2
  fea335555= f0a335555 + f1a335555*coro+ f2a335555*coro**2
  fea334455= f0a334455 + f1a334455*coro+ f2a334455*coro**2
  fea334445= f0a334445 + f1a334445*coro+ f2a334445*coro**2
  fea333555= f0a333555 + f1a333555*coro+ f2a333555*coro**2
  fea333333= f0a333333 + f1a333333*coro+ f2a333333*coro**2
  fea244555= f0a244555 + f1a244555*coro+ f2a244555*coro**2
  fea244455= f0a244455 + f1a244455*coro+ f2a244455*coro**2
  fea233445= f0a233445 + f1a233445*coro+ f2a233445*coro**2
  fea233444= f0a233444 + f1a233444*coro+ f2a233444*coro**2
  fea233345= f0a233345 + f1a233345*coro+ f2a233345*coro**2
  fea233344= f0a233344 + f1a233344*coro+ f2a233344*coro**2
  fea233335= f0a233335 + f1a233335*coro+ f2a233335*coro**2
  fea223355= f0a223355 + f1a223355*coro+ f2a223355*coro**2
  fea222335= f0a222335 + f1a222335*coro+ f2a222335*coro**2
  fea222334= f0a222334 + f1a222334*coro+ f2a222334*coro**2
  fea222333= f0a222333 + f1a222333*coro+ f2a222333*coro**2
  fea222255= f0a222255 + f1a222255*coro+ f2a222255*coro**2
  fea222245= f0a222245 + f1a222245*coro+ f2a222245*coro**2
  fea222233= f0a222233 + f1a222233*coro+ f2a222233*coro**2
  fea222224= f0a222224 + f1a222224*coro+ f2a222224*coro**2
  fea145555= f0a145555 + f1a145555*coro+ f2a145555*coro**2
  fea134444= f0a134444 + f1a134444*coro+ f2a134444*coro**2
  fea133444= f0a133444 + f1a133444*coro+ f2a133444*coro**2
  fea133345= f0a133345 + f1a133345*coro+ f2a133345*coro**2
  fea133334= f0a133334 + f1a133334*coro+ f2a133334*coro**2
  fea133333= f0a133333 + f1a133333*coro+ f2a133333*coro**2
  fea124555= f0a124555 + f1a124555*coro+ f2a124555*coro**2
  fea124455= f0a124455 + f1a124455*coro+ f2a124455*coro**2
  fea123455= f0a123455 + f1a123455*coro+ f2a123455*coro**2
  fea123345= f0a123345 + f1a123345*coro+ f2a123345*coro**2
  fea113555= f0a113555 + f1a113555*coro+ f2a113555*coro**2
  fea113345= f0a113345 + f1a113345*coro+ f2a113345*coro**2
  fea112355= f0a112355 + f1a112355*coro+ f2a112355*coro**2
  fea112335= f0a112335 + f1a112335*coro+ f2a112335*coro**2
  fea112233= f0a112233 + f1a112233*coro+ f2a112233*coro**2
  fea111444= f0a111444 + f1a111444*coro+ f2a111444*coro**2
  fea111234= f0a111234 + f1a111234*coro+ f2a111234*coro**2
  fea111233= f0a111233 + f1a111233*coro+ f2a111233*coro**2
  fea111123= f0a111123 + f1a111123*coro+ f2a111123*coro**2


  v1=0;v2=0;v3=0;v4=0;v5=0;v6=0;
  if (order>=1) then 
      v1 = (y3+y2+y1)*fea1
  endif

  if (order>=2) then 
      v2 = (y2*y3+y1*y3+y1*y2)*fea12                                                                 &
       +(y2**2+y3**2+y1**2)*fea11                                                                    &
       +(-sqrt(3.0d0)*y3*y5/2.0d0-y3*y4/2.0d0+y1*y4+sqrt(3.0d0)*y2*y5/2.0d0-y2*y4/2.0d0)*fea14 &
       +(y5**2+y4**2)*fea44
  endif

  if (order>=3) then 

      v3 = (y1*y3*y4+y1*y2*y4-2.0d0*y2*y3*y4+sqrt(3.0d0)*y1*y2*y5-sqrt(3.0d0)*y1*y3*y5)*fea124   &
       +(3.0d0/4.0d0*y3*y4**2-sqrt(3.0d0)*y3*y4*y5/2.0d0+y1*y5**2+y2*y5**2/4.0d0               & 
       +3.0d0/4.0d0*y2*y4**2+sqrt(3.0d0)*y2*y4*y5/2.0d0+y3*y5**2/4.0d0)*fea155                 &
       +(y2*y3**2+y1*y3**2+y1**2*y3+y1*y2**2+y2**2*y3+y1**2*y2)*fea112+                             &
       (-y4**3/3.0d0+y4*y5**2)*fea455+fea123*y1*y2*y3                                              &
       +(y1*y4**2+3.0d0/4.0d0*y3*y5**2+3.0d0/4.0d0*y2*y5**2+y2*y4**2/4.0d0                     &
       -sqrt(3.0d0)*y2*y4*y5/2.0d0+sqrt(3.0d0)*y3*y4*y5/2.0d0+y3*y4**2/4.0d0)*fea144           &
       +(y3**3+y2**3+y1**3)*fea111+(-y2**2*y4/2.0d0-y3**2*y4/2.0d0+sqrt(3.0d0)*y2**2*y5/2.0d0   & 
       +y1**2*y4-sqrt(3.0d0)*y3**2*y5/2.0d0)*fea114
  endif

  if (order>=4) then 
       !
      s2 = (y4**4+y5**4+2.0d0*y4**2*y5**2)*fea4444+(3.0d0/8.0d0*sqrt(3.0d0)*&
       y2*y5**3-3.0d0/8.0d0*sqrt(3.0d0)*y3*y4**2*y5-3.0d0/8.0d0*sqrt(3.0d0)*y3*&
       y5**3-9.0d0/8.0d0*y2*y4*y5**2-y3*y4**3/8.0d0-y2*y4**3/8.0d0-9.0d0/8.0d0*&
       y3*y4*y5**2+y1*y4**3+3.0d0/8.0d0*sqrt(3.0d0)*y2*y4**2*y5)*fea1444 &
       +(3.0d0/4.0d0*y2**2*y4**2+3.0d0/4.0d0*y3**2*y4**2+y1**2*y5**2+y3**2*y5**2/4.0d0 &
       -sqrt(3.0d0)*y3**2*y4*y5/2.0d0+sqrt(3.0d0)*y2**2*y4*y5/2.0d0+y2**2&
       *y5**2/4.0d0)*fea1155 
       s1 = s2+(y3**2*y4**2/4.0d0+3.0d0/4.0d0*y3**2*y5**2+y1**2*y4**2+y2**2*&
       y4**2/4.0d0+sqrt(3.0d0)*y3**2*y4*y5/2.0d0-sqrt(3.0d0)*y2**2*y4*y5/2.0d0&
       +3.0d0/4.0d0*y2**2*y5**2)*fea1144+(y1**3*y4+sqrt(3.0d0)*y2**3*y5/2.0d0&
       -sqrt(3.0d0)*y3**3*y5/2.0d0-y2**3*y4/2.0d0-y3**3*y4/2.0d0)*fea1114&
       +(y2**4+y1**4+y3**4)*fea1111+(sqrt(3.0d0)*y1*y3*y4*y5+3.0d0/2.0d0*y2*y3*y5**2&
       -y2*y3*y4**2/2.0d0+y1*y2*y4**2-sqrt(3.0d0)*y1*y2*y4*y5+y1*y3*y4**2)*fea1244 
       !
      s2 = s1+(y1*y3*y5**2+y1*y2*y5**2-sqrt(3.0d0)*y1*y3*y4*y5-y2*y3*y5**&
       2/2.0d0+3.0d0/2.0d0*y2*y3*y4**2+sqrt(3.0d0)*y1*y2*y4*y5)*fea1255+&
       (-y1*y3**2*y4/2.0d0+y1**2*y3*y4-sqrt(3.0d0)*y1*y3**2*y5/2.0d0-sqrt(3.0d0)*y2&
       *y3**2*y5/2.0d0+y1**2*y2*y4+sqrt(3.0d0)*y2**2*y3*y5/2.0d0-y2**2*y3*y4&
       /2.0d0+sqrt(3.0d0)*y1*y2**2*y5/2.0d0-y2*y3**2*y4/2.0d0-y1*y2**2*y4/2.0d0&
       )*fea1124+(y1**2*y2*y5+sqrt(3.0d0)*y1*y3**2*y4/2.0d0+sqrt(3.0d0)*y1*&
       y2**2*y4/2.0d0-sqrt(3.0d0)*y2*y3**2*y4/2.0d0-sqrt(3.0d0)*y2**2*y3*y4/2.0d0&
       -y2**2*y3*y5/2.0d0+y2*y3**2*y5/2.0d0-y1*y3**2*y5/2.0d0+y1*y2**2*y5&
       /2.0d0-y1**2*y3*y5)*fea1125 
       !
      v4 = s2+(y2*y3**3+y1**3*y3+y1**3*y2+y1*y2**3+y1*y3**3+y2**3*y3)*fea1112+&
       (y2**2*y3**2+y1**2*y3**2+y1**2*y2**2)*fea1122+(y1*y2**2*y3&
       +y1**2*y2*y3+y1*y2*y3**2)*fea1123+(5.0d0/8.0d0*y2*y4*y5**2+sqrt(3.0d0)*&
       y2*y5**3/8.0d0-sqrt(3.0d0)*y3*y4**2*y5/8.0d0+sqrt(3.0d0)*y2*y4**2*y5/8.0d0&
       -3.0d0/8.0d0*y2*y4**3+y1*y4*y5**2-sqrt(3.0d0)*y3*y5**3/8.0d0&
       +5.0d0/8.0d0*y3*y4*y5**2-3.0d0/8.0d0*y3*y4**3)*fea1455

  endif

  if (order>=5) then 
     
s3 = (y4**5-2.0d0*y4**3*y5**2-3.0d0*y4*y5**4)*fea44444+(-4.0d0*y3*y4*&
y5**3*sqrt(3.0d0)+9.0d0*y1*y4**2*y5**2-3.0d0/2.0d0*y1*y4**4+4.0d0*y2*y4&
*y5**3*sqrt(3.0d0)+3.0d0*y2*y4**4+5.0d0/2.0d0*y1*y5**4+3.0d0*y3*y4**4+&
y2*y5**4+y3*y5**4)*fea25555+(-y2*y4**4+y3*y4**2*y5**2-2.0d0*y2*y4*y5&
**3*sqrt(3.0d0)-y3*y4**4-7.0d0/2.0d0*y1*y4**2*y5**2-3.0d0/4.0d0*y1*y5**4&
+2.0d0*y3*y4*y5**3*sqrt(3.0d0)+y2*y4**2*y5**2+5.0d0/4.0d0*y1*y4**4)*fea24455 
!
s2 = s3+(y2*y4**3*y5-3.0d0*y3*y4*y5**3+2.0d0/3.0d0*y3*y4**4*sqrt(3.0d0&
)+3.0d0/4.0d0*y1*y5**4*sqrt(3.0d0)+3.0d0*y2*y4*y5**3-&
7.0d0/12.0d0*y1*y4**4*sqrt(3.0d0)+3.0d0/2.0d0*y1*y4**2*y5**2*sqrt(3.0d0)-y3*y4**3*y5&
+2.0d0/3.0d0*y2*y4**4*sqrt(3.0d0))*fea24445+(-y2**2*y5**3+y3**2*y4**2*y5+ &
y3**2*y5**3+4.0d0/9.0d0*y2**2*y4**3*sqrt(3.0d0)-5.0d0/9.0d0*y1**2*y4**3*&
sqrt(3.0d0)+4.0d0/9.0d0*y3**2*y4**3*sqrt(3.0d0)-y2**2*y4**2*y5&
-y1**2*y4*y5**2*sqrt(3.0d0))*fea33445+(y3**2*y4*y5**2-y1**2*y4**3/3.0d0&
-y3**2*y4**3/3.0d0+y1**2*y4*y5**2+y2**2*y4*y5**2-y2**2*y4**3/3.0d0)*fea33455 
!
s1 = s2+(-y2**3*y4*y5+y3**3*y4*y5+y2**3*y5**2*sqrt(3.0d0)/3.0d0+y1**&
3*y4**2*sqrt(3.0d0)/2.0d0+y3**3*y5**2*sqrt(3.0d0)/3.0d0- & 
y1**3*y5**2*sqrt(3.0d0)/6.0d0)*fea33345+(y3**3*y4**2+y3**3*y5**2+y2**3*y4**2+y2**3&
*y5**2+y1**3*y5**2+y1**3*y4**2)*fea33344+(y3**4*y4+sqrt(3.0d0)*y3**&
4*y5+y2**4*y4-2.0d0*y1**4*y4-sqrt(3.0d0)*y2**4*y5)*fea33334+(y2**5+ &
y3**5+y1**5)*fea33333+(-4.0d0/9.0d0*y1*y2*y4**3*sqrt(3.0d0)-y1*y2*y5**3+ &
y1*y3*y4**2*y5+y2*y3*y4*y5**2*sqrt(3.0d0)-y1*y2*y4**2*y5+5.0d0/9.0d0&
*y2*y3*y4**3*sqrt(3.0d0)-4.0d0/9.0d0*y1*y3*y4**3*sqrt(3.0d0)+y1*y3*y5&
**3)*fea13445+(y2*y3*y4*y5**2+y1*y2*y4*y5**2-y2*y3*y4**3/3.0d0- & 
y1*y2*y4**3/3.0d0-y1*y3*y4**3/3.0d0+y1*y3*y4*y5**2)*fea13455 

s3 = s1+(y1**2*y3*y5**2+y2**2*y3*y4**2+y2**2*y3*y5**2+y1*y2**2*y5**2+&
y1**2*y2*y5**2+y1*y2**2*y4**2+y2*y3**2*y4**2+y1*y3**2*y4**2+&
y1**2*y3*y4**2+y1**2*y2*y4**2+y1*y3**2*y5**2+y2*y3**2*y5**2)*fea11255&
+(2.0d0/3.0d0*y1**2*y3*y4**2*sqrt(3.0d0)+y1*y3**2*y5**2*sqrt(3.0d0)/2.0d0+&
y1*y2**2*y5**2*sqrt(3.0d0)/2.0d0+y2**2*y3*y5**2*sqrt(3.0d0)/2.0d0-&
y1*y2**2*y4*y5+y2*y3**2*y4*y5+y1*y3**2*y4*y5-y2**2*y3*y4*y5+y2*y3**&
2*y4**2*sqrt(3.0d0)/6.0d0+y1*y3**2*y4**2*sqrt(3.0d0)/6.0d0+y1*y2**2*y4&
**2*sqrt(3.0d0)/6.0d0+2.0d0/3.0d0*y1**2*y2*y4**2*sqrt(3.0d0)+&
y2*y3**2*y5**2*sqrt(3.0d0)/2.0d0+y2**2*y3*y4**2*sqrt(3.0d0)/6.0d0)*fea13345 
s4 = s3+(y1**2*y2*y4*y5+y1**2*y3*y4**2*sqrt(3.0d0)/3.0d0+y1**2*y2*y4&
**2*sqrt(3.0d0)/3.0d0-y1*y2**2*y4**2*sqrt(3.0d0)/6.0d0+y2*y3**2*y4*y5-&
y2**2*y3*y4*y5-y1**2*y3*y4*y5+y2*y3**2*y4**2*sqrt(3.0d0)/3.0d0+y1*y2&
**2*y5**2*sqrt(3.0d0)/2.0d0-y1*y3**2*y4**2*sqrt(3.0d0)/6.0d0+y2**2*y3*&
y4**2*sqrt(3.0d0)/3.0d0+y1*y3**2*y5**2*sqrt(3.0d0)/2.0d0)*fea11245 
s2 = s4+(-y1**3*y2*y5+y1**3*y3*y5+y2**3*y3*y5/2.0d0-y1*y2**3*y4*sqrt(3.0d0)/2.0d0-&
y1*y2**3*y5/2.0d0-y2*y3**3*y5/2.0d0+y1*y3**3*y5/2.0d0+y2&
**3*y3*y4*sqrt(3.0d0)/2.0d0+y2*y3**3*y4*sqrt(3.0d0)/2.0d0-y1*y3**3*y4*&
sqrt(3.0d0)/2.0d0)*fea11135+(y1**3*y3*y4-y2**3*y3*y4/2.0d0+y1**3*y2*y4-&
y2*y3**3*y4/2.0d0-y1*y3**3*y4/2.0d0+y1*y2**3*y5*sqrt(3.0d0)/2.0d0+y2&
**3*y3*y5*sqrt(3.0d0)/2.0d0-y2*y3**3*y5*sqrt(3.0d0)/2.0d0-y1*y2**3*y4/&
2.0d0-y1*y3**3*y5*sqrt(3.0d0)/2.0d0)*fea11134 

v5 = s2+(y1*y2**4+y1**4*y3+y1**4*y2+y2**4*y3+y2*y3**4+y1*y3**4)*fea23333+&
(-2.0d0*y2**2*y3**2*y4+y1**2*y2**2*y4-sqrt(3.0d0)*y1**2*y3**2&
*y5+sqrt(3.0d0)*y1**2*y2**2*y5+y1**2*y3**2*y4)*fea11334+(y1**2*y3**&
3+y1**3*y3**2+y2**2*y3**3+y1**2*y2**3+y1**3*y2**2+y2**3*y3**2)*fea11333+&
(y1*y2*y3*y4**2+y1*y2*y3*y5**2)*fea12355+(-y1*y2*y3**2*y4/2.0d0-&
y1*y2**2*y3*y4/2.0d0-sqrt(3.0d0)*y1*y2*y3**2*y5/2.0d0+y1**2*y2*y3*y4+&
sqrt(3.0d0)*y1*y2**2*y3*y5/2.0d0)*fea11234+(y1*y2**3*y3+y1*y2*y3**3+&
y1**3*y2*y3)*fea11123+(y1**2*y2**2*y3+y1*y2**2*y3**2+y1**2*y2*y3**2)*fea11233
   endif

  if (order>=6) then 


s3 = (y2**3*y4**3*sqrt(3.0d0)-y2**3*y4**2*y5+y3**3*y4**2*y5-&
5.0d0/3.0d0*y2**3*y4*y5**2*sqrt(3.0d0)+y3**3*y4**3*sqrt(3.0d0)-5.0d0/3.0d0*y3**&
3*y4*y5**2*sqrt(3.0d0)-y2**3*y5**3+y3**3*y5**3-8.0d0/3.0d0*y1**3*y4*y5**2*sqrt(3.0d0))*fea333555+&
(y1**4*y5**2*sqrt(3.0d0)/2.0d0+y2**4*y4*y5+y2**4*y4**2*sqrt(3.0d0)/3.0d0+&
y3**4*y4**2*sqrt(3.0d0)/3.0d0-y3**4*y4&
*y5-y1**4*y4**2*sqrt(3.0d0)/6.0d0)*fea222245+(y1*y3**5+y1*y2**5+y2**&
5*y3+y1**5*y3+y1**5*y2+y2*y3**5)*fea133333+(y1**4*y3*y4-2.0d0*y2**4&
*y3*y4+y1**4*y2*y4+y1*y2**4*y5*sqrt(3.0d0)+y1*y3**4*y4-2.0d0*y2*y3**&
4*y4+y1**4*y2*y5*sqrt(3.0d0)-y1*y3**4*y5*sqrt(3.0d0)-y1**4*y3*y5*sqrt(3.0d0)+&
y1*y2**4*y4)*fea133334+(-y1*y2*y3*y4**3/3.0d0+y1*y2*y3*y4*y5**2)*fea123455 

s4 = s3+(2.0d0/3.0d0*sqrt(3.0d0)*y1*y2**2*y3**2*y4-y1**2*y2**2*y3*y5-&
sqrt(3.0d0)*y1**2*y2**2*y3*y4/3.0d0+y1**2*y2*y3**2*y5-&
sqrt(3.0d0)*y1**2*y2*y3**2*y4/3.0d0)*fea112335+(y1*y2**2*y3*y5**2+y1*y2*y3**2*y5**2+&
y1*y2*y3**2*y4**2+y1*y2**2*y3*y4**2+y1**2*y2*y3*y4**2+y1**2*y2*y3*y5**2)*fea112355 

s2 = s4+(y2**3*y3**2*y5-y1**3*y2**2*y5/2.0d0-y1**2*y3**3*y5/2.0d0-y2&
**2*y3**3*y5+y1**3*y2**2*y4*sqrt(3.0d0)/2.0d0-y1**2*y2**3*y4*sqrt(3.0d0)/2.0d0+&
y1**3*y3**2*y5/2.0d0+y1**2*y2**3*y5/2.0d0+y1**3*y3**2*y4*sqrt(3.0d0)/2.0d0-&
y1**2*y3**3*y4*sqrt(3.0d0)/2.0d0)*fea222335+(-y1**2*y2&
**2*y5**2*sqrt(3.0d0)/2.0d0-y1**2*y3**2*y5**2*sqrt(3.0d0)/2.0d0-y1**2*&
y2**2*y4**2*sqrt(3.0d0)/6.0d0-y1**2*y2**2*y4*y5-2.0d0/3.0d0*y2**2*y3**&
2*y4**2*sqrt(3.0d0)+y1**2*y3**2*y4*y5-y1**2*y3**2*y4**2*sqrt(3.0d0)/&
6.0d0)*fea113345+(y2**2*y3**2*y5**2+y2**2*y3**2*y4**2+y1**2*y2**2*y5**2+&
y1**2*y3**2*y4**2+y1**2*y3**2*y5**2+y1**2*y2**2*y4**2)*fea223355 

s3 = s2+(y1*y2*y3**2*y4**2*sqrt(3.0d0)/6.0d0+y1*y2*y3**2*y4*y5+y1*y2&
*y3**2*y5**2*sqrt(3.0d0)/2.0d0+2.0d0/3.0d0*y1**2*y2*y3*y4**2*sqrt(3.0d0&
)-y1*y2**2*y3*y4*y5+y1*y2**2*y3*y4**2*sqrt(3.0d0)/6.0d0+y1*y2**2*y3*&
y5**2*sqrt(3.0d0)/2.0d0)*fea123345+(-y1**3*y2**2*y5*sqrt(3.0d0)/2.0d0-&
y1**3*y2**2*y4/2.0d0-y1**3*y3**2*y4/2.0d0-y1**2*y2**3*y4/2.0d0+y1**3*&
y3**2*y5*sqrt(3.0d0)/2.0d0-y1**2*y3**3*y4/2.0d0+y2**3*y3**2*y4-y1**2*&
y2**3*y5*sqrt(3.0d0)/2.0d0+y2**2*y3**3*y4+y1**2*y3**3*y5*sqrt(3.0d0)/&
2.0d0)*fea222334+(3.0d0*y3**2*y4**4+5.0d0/2.0d0*y1**2*y5**4+y2**2*y5**&
4+3.0d0*y2**2*y4**4-4.0d0*y3**2*y4*y5**3*sqrt(3.0d0)+y3**2*y5**4+9.0d0&
*y1**2*y4**2*y5**2-3.0d0/2.0d0*y1**2*y4**4+4.0d0*y2**2*y4*y5**3*sqrt(&
3.0d0))*fea335555+(y1**3*y2**3+y1**3*y3**3+y2**3*y3**3)*fea222333 

s4 = s3+(y3*y4**5/5.0d0-y2*y4**4*y5*sqrt(3.0d0)/2.0d0-2.0d0/5.0d0*y1*y4&
**5-2.0d0*y1*y4**3*y5**2-3.0d0/10.0d0*y2*y5**5*sqrt(3.0d0)+y3*y4**3*y5&
**2+y3*y4**4*y5*sqrt(3.0d0)/2.0d0+y2*y4**3*y5**2+3.0d0/10.0d0*y3*y5**5&
*sqrt(3.0d0)+y2*y4**5/5.0d0)*fea244455+(y2**5*y4-2.0d0*y1**5*y4-sqrt(&
3.0d0)*y2**5*y5+y3**5*y4+sqrt(3.0d0)*y3**5*y5)*fea222224 

s5 = s4+(-y3*y5**5*sqrt(3.0d0)/5.0d0+y2*y5**5*sqrt(3.0d0)/5.0d0+y1*y4*&
y5**4-7.0d0/15.0d0*y2*y4**5+y2*y4**4*y5*sqrt(3.0d0)/3.0d0-y3*y4**4*y5*&
sqrt(3.0d0)/3.0d0+y3*y4*y5**4+y2*y4*y5**4+2.0d0*y1*y4**3*y5**2-7.0d0/15.0d0*y3*y4**5-&
y1*y4**5/15.0d0)*fea145555 

s1 = s5+(-sqrt(3.0d0)*y1*y2*y3**3*y5/2.0d0+y1**3*y2*y3*y4+sqrt(3.0d0)&
*y1*y2**3*y3*y5/2.0d0-y1*y2**3*y3*y4/2.0d0-y1*y2*y3**3*y4/2.0d0)*fea111234+&
(y3*y4**4*y5/3.0d0+y3*y4**5*sqrt(3.0d0)/18.0d0-y2*y4**4*y5/3.0d0&
-y2*y4*y5**4*sqrt(3.0d0)/2.0d0-y3*y4**2*y5**3+2.0d0/9.0d0*y1*y4**5*sqrt(3.0d0)+&
y2*y4**5*sqrt(3.0d0)/18.0d0+y2*y4**2*y5**3-2.0d0/3.0d0*y1*y4**&
3*y5**2*sqrt(3.0d0)-y3*y4*y5**4*sqrt(3.0d0)/2.0d0)*fea244555+(y1*y2*y4**2*y5**2-&
3.0d0/4.0d0*y2*y3*y4**4-y1*y2*y5**4-y1*y3*y5**4+5.0d0/4.0d0*y2*y3*y5**4+&
y1*y3*y4**2*y5**2-7.0d0/2.0d0*y2*y3*y4**2*y5**2-2.0d0*y1&
*y2*y4**3*y5*sqrt(3.0d0)+2.0d0*y1*y3*y4**3*y5*sqrt(3.0d0))*fea124455 

s3 = s1+(y2**6+y1**6+y3**6)*fea333333+(y1*y2**4*y3+y1**4*y2*y3+y1*&
y2*y3**4)*fea111123+fea112233*y1**2*y2**2*y3**2+(y1**4*y4**2+y2**4&
*y4**2+y2**4*y5**2+y3**4*y4**2+y1**4*y5**2+y3**4*y5**2)*fea222255 
s4 = s3+(3.0d0*y1*y3*y5**4+y1*y3*y4**4+9.0d0*y2*y3*y4**2*y5**2-3.0d0/&
2.0d0*y2*y3*y5**4-4.0d0*y1*y3*y4**3*y5*sqrt(3.0d0)+y1*y2*y4**4+&
4.0d0*y1*y2*y4**3*y5*sqrt(3.0d0)+3.0d0*y1*y2*y5**4+5.0d0/2.0d0*y2*y3*y4**4)*fea134444+&
(-y1*y3**2*y5**3*sqrt(3.0d0)/3.0d0-7.0d0/3.0d0*y1**2*y3*y4*y5&
**2+5.0d0/3.0d0*y1*y2**2*y4**2*y5*sqrt(3.0d0)-13.0d0/3.0d0*y2**2*y3*y4*&
y5**2-4.0d0/3.0d0*y2*y3**2*y5**3*sqrt(3.0d0)-7.0d0/3.0d0*y1**2*y2*y4*y5&
**2-16.0d0/3.0d0*y1*y3**2*y4*y5**2+4.0d0/3.0d0*y1**2*y3*y4**2*y5*sqrt(&
3.0d0)+4.0d0/3.0d0*y2**2*y3*y5**3*sqrt(3.0d0)+3.0d0*y1**2*y2*y4**3+&
y2*y3**2*y4**3+y1*y2**2*y5**3*sqrt(3.0d0)/3.0d0+y2**2*y3*y4**3-13.0d0/3.0d0&
*y2*y3**2*y4*y5**2-5.0d0/3.0d0*y1*y3**2*y4**2*y5*sqrt(3.0d0)-&
4.0d0/3.0d0*y1**2*y2*y4**2*y5*sqrt(3.0d0)+3.0d0*y1**2*y3*y4**3-16.0d0/3.0d0*y1*&
y2**2*y4*y5**2)*fea233444 

s5 = s4+(2.0d0*y1*y3**2*y5**3+4.0d0*y2*y3**2*y5**3+4.0d0*y2**2*y3*y4*&
y5**2*sqrt(3.0d0)-2.0d0*y1*y2**2*y5**3+y1**2*y3*y4*y5**2*sqrt(3.0d0)+&
6.0d0*y1*y3**2*y4**2*y5-6.0d0*y1*y2**2*y4**2*y5-3.0d0*y1**2*y3*y4**2*&
y5+y1**2*y2*y4*y5**2*sqrt(3.0d0)+4.0d0*y1*y3**2*y4*y5**2*sqrt(3.0d0)-&
3.0d0*y1**2*y2*y4**3*sqrt(3.0d0)-4.0d0*y2**2*y3*y5**3+3.0d0*y1**2*y2*y4**2*y5-&
y1**2*y2*y5**3+y1**2*y3*y5**3-3.0d0*y1**2*y3*y4**3*sqrt(3.0d0&
)+4.0d0*y2*y3**2*y4*y5**2*sqrt(3.0d0)+4.0d0*y1*y2**2*y4*y5**2*sqrt(3.0d0))*fea113555 

s2 = s5+(-2.0d0/3.0d0*y3**2*y4**4*sqrt(3.0d0)-3.0d0/2.0d0*y1**2*y4**2*y5**2*sqrt(3.0d0)-&
3.0d0/4.0d0*y1**2*y5**4*sqrt(3.0d0)-y2**2*y4**3*y5+&
7.0d0/12.0d0*y1**2*y4**4*sqrt(3.0d0)+y3**2*y4**3*y5+3.0d0*y3**2*y4*y5**3&
-2.0d0/3.0d0*y2**2*y4**4*sqrt(3.0d0)-3.0d0*y2**2*y4*y5**3)*fea334445+(&
-3.0d0*y1*y3*y4**3*y5+2.0d0/3.0d0*y1*y2*y5**4*sqrt(3.0d0)-y1*y3*y4*y5**3+&
2.0d0/3.0d0*y1*y3*y5**4*sqrt(3.0d0)+3.0d0*y1*y2*y4**3*y5-7.0d0/12.0d0&
*y2*y3*y5**4*sqrt(3.0d0)+3.0d0/2.0d0*y2*y3*y4**2*y5**2*sqrt(3.0d0)+y1*&
y2*y4*y5**3+3.0d0/4.0d0*y2*y3*y4**4*sqrt(3.0d0))*fea124555+(2.0d0*y3**&
2*y4*y5**3*sqrt(3.0d0)-7.0d0/2.0d0*y1**2*y4**2*y5**2+y2**2*y4**2*y5**&
2-y2**2*y4**4-y3**2*y4**4-2.0d0*y2**2*y4*y5**3*sqrt(3.0d0)-3.0d0/4.0d0&
*y1**2*y5**4+5.0d0/4.0d0*y1**2*y4**4+y3**2*y4**2*y5**2)*fea334455 
s3 = s2+(-6.0d0*y4**2*y5**4+9.0d0*y4**4*y5**2+y5**6)*fea555555+(y2*y3**3*y4**2+&
y2*y3**3*y5**2+y1*y3**3*y4**2+y1*y2**3*y4**2+y1**3*y2*y4**2+&
y1*y2**3*y5**2+y1**3*y3*y5**2+y1**3*y3*y4**2+y1**3*y2*y5**2+y2**3*y3*y4**2+&
y1*y3**3*y5**2+y2**3*y3*y5**2)*fea233344+(y1*y2**3*y5**2*sqrt(3.0d0)/6.0d0-&
y2**3*y3*y5**2*sqrt(3.0d0)/3.0d0-y2*y3**3*y5**2&
*sqrt(3.0d0)/3.0d0+y1**3*y2*y4*y5-y1**3*y2*y5**2*sqrt(3.0d0)/3.0d0-&
y1**3*y3*y4*y5-y1**3*y3*y5**2*sqrt(3.0d0)/3.0d0-y1*y3**3*y4**2*sqrt(3.0d0&
)/2.0d0+y1*y3**3*y5**2*sqrt(3.0d0)/6.0d0-y2**3*y3*y4*y5+y2*y3**3*y4*&
y5-y1*y2**3*y4**2*sqrt(3.0d0)/2.0d0)*fea233345+(-3.0d0*y2**3*y4*y5**2&
+y3**3*y4**3-3.0d0*y3**3*y4*y5**2-3.0d0*y1**3*y4*y5**2+y2**3*y4**3+&
y1**3*y4**3)*fea111444+(y1*y2**3*y3**2+y1**3*y2**2*y3+y1**2*y2**3*y3+&
y1*y2**2*y3**3+y1**2*y2*y3**3+y1**3*y2*y3**2)*fea111233 

s4 = s3+(9.0d0*y4**2*y5**4-6.0d0*y4**4*y5**2+y4**6)*fea444444+(-5.0d0&
/3.0d0*y1*y2**2*y4**2*y5*sqrt(3.0d0)+y1*y2**2*y4**3-4.0d0/3.0d0*y1**2*&
y3*y4**2*y5*sqrt(3.0d0)-2.0d0*y1**2*y2*y4**3-y1*y2**2*y5**3*sqrt(3.0d0&
)/3.0d0+4.0d0/3.0d0*y2**2*y3*y4*y5**2-4.0d0/3.0d0*y2**2*y3*y5**3*sqrt(&
3.0d0)-2.0d0*y1**2*y3*y4**3+7.0d0/3.0d0*y1*y2**2*y4*y5**2-2.0d0/3.0d0*y1&
**2*y3*y4*y5**2+y1*y3**2*y4**3+4.0d0/3.0d0*y2*y3**2*y5**3*sqrt(3.0d0)&
+y1*y3**2*y5**3*sqrt(3.0d0)/3.0d0+4.0d0/3.0d0*y1**2*y2*y4**2*y5*sqrt(3.0d0)&
+4.0d0/3.0d0*y2*y3**2*y4*y5**2+5.0d0/3.0d0*y1*y3**2*y4**2*y5*sqrt(&
3.0d0)-2.0d0/3.0d0*y1**2*y2*y4*y5**2+7.0d0/3.0d0*y1*y3**2*y4*y5**2)*fea133444 

s5 = s4+(-y1**3*y2*y4*y5+2.0d0/3.0d0*y2**3*y3*y5**2*sqrt(3.0d0)+y1*y3&
**3*y4**2*sqrt(3.0d0)/2.0d0+y1**3*y3*y4**2*sqrt(3.0d0)/2.0d0+y1**3*y3*&
y5**2*sqrt(3.0d0)/6.0d0+y1**3*y2*y5**2*sqrt(3.0d0)/6.0d0+y1**3*y3*y4*y5+&
y1*y2**3*y5**2*sqrt(3.0d0)/6.0d0+y1**3*y2*y4**2*sqrt(3.0d0)/2.0d0+&
2.0d0/3.0d0*y2*y3**3*y5**2*sqrt(3.0d0)-y1*y2**3*y4*y5+y1*y2**3*y4**2*sqrt(3.0d0)/2.0d0+&
y1*y3**3*y5**2*sqrt(3.0d0)/6.0d0+y1*y3**3*y4*y5)*fea133345 

v6 = s5+(-y2**2*y3*y4**2*y5+y1**2*y3*y4*y5**2*sqrt(3.0d0)/3.0d0+y2*y3**2*y4**2*y5+&
y2*y3**2*y5**3-y1*y2**2*y5**3+4.0d0/3.0d0*y2**2*y3*y4*&
y5**2*sqrt(3.0d0)+4.0d0/3.0d0*y2*y3**2*y4*y5**2*sqrt(3.0d0)-y1*y2**2*y4**2*y5+&
4.0d0/3.0d0*y1*y3**2*y4*y5**2*sqrt(3.0d0)-y2**2*y3*y5**3+y1*y3**2*y5**3+&
y1**2*y2*y4*y5**2*sqrt(3.0d0)/3.0d0-y1**2*y2*y4**3*sqrt(3.0d0)&
+y1*y3**2*y4**2*y5-y1**2*y3*y4**3*sqrt(3.0d0)+4.0d0/3.0d0*y1*y2**&
2*y4*y5**2*sqrt(3.0d0))*fea233445+(y2*y3**4*y4*sqrt(3.0d0)-y1**4*y2*&
y5+y2**4*y3*y4*sqrt(3.0d0)-y1**4*y3*y4*sqrt(3.0d0)+y2*y3**4*y5-2.0d0*&
y1*y2**4*y5+2.0d0*y1*y3**4*y5-y1**4*y2*y4*sqrt(3.0d0)+y1**4*y3*y5-y2&
**4*y3*y5)*fea233335+(y2**2*y3**4+y1**4*y3**2+y1**2*y2**4+y2**4*y3&
**2+y1**2*y3**4+y1**4*y2**2)*fea222233
  endif



  potential = v0+v1+v2+v3+v4+v5+v6

 end function potential


!
!   Skip n lines  in the input file 
!
  subroutine skiplines( inpunit,n )
  integer,intent(in) :: n,inpunit
  character(len=80)  :: label
  integer            :: i0

    do i0=1,n
       read  (inpunit,"(a80)") label 
    enddo

  end subroutine skiplines


